@@ -1,9 +1,9 @@
 import random
 
 # Шифровка
-def enscrypt(text):
+def ENS(text):
 
-     #Символы
+    #Символы
     sSym = '&$%@=¿!qwertyuiopasdfghjklzxcvbnm1234567890'
     
     tx = ''
@@ -48,9 +48,9 @@ def enscrypt(text):
     return tx
 
 # Расшифровка
-def decrypt(text):
+def DEC(text):
 
-     #Символы
+    #Символы
     sSym = '&$%@=¿!qwertyuiopasdfghjklzxcvbnm1234567890'
 
     tx = ''
@@ -75,6 +75,4 @@ def decrypt(text):
     else:
         tx = ''
     
-    return tx
-
-print(enscrypt('this is text'))
\ No newline at end of file
+    return tx
\ No newline at end of file
